<?php

namespace Assetdocs\Client\Http\Controllers\Api;

use App\Http\Controllers\Api\AdminController as BaseController;
use Assetdocs\Client\Http\Requests\AppclientRequest;
use Assetdocs\Client\Interfaces\AppclientRepositoryInterface;
use Assetdocs\Client\Models\Appclient;

/**
 * Admin API controller class.
 */
class AppclientAdminController extends BaseController
{
    /**
     * Initialize appclient controller.
     *
     * @param type AppclientRepositoryInterface $appclient
     *
     * @return type
     */
    public function __construct(AppclientRepositoryInterface $appclient)
    {
        $this->repository = $appclient;
        parent::__construct();
    }

    /**
     * Display a list of appclient.
     *
     * @return json
     */
    public function index(AppclientRequest $request)
    {
        $appclients  = $this->repository
            ->setPresenter('\\Assetdocs\\Client\\Repositories\\Presenter\\AppclientListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $appclients['code'] = 2000;
        return response()->json($appclients) 
                         ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display appclient.
     *
     * @param Request $request
     * @param Model   Appclient
     *
     * @return Json
     */
    public function show(AppclientRequest $request, Appclient $appclient)
    {
        $appclient         = $appclient->presenter();
        $appclient['code'] = 2001;
        return response()->json($appclient)
                         ->setStatusCode(200, 'SHOW_SUCCESS');;

    }

    /**
     * Show the form for creating a new appclient.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(AppclientRequest $request, Appclient $appclient)
    {
        $appclient         = $appclient->presenter();
        $appclient['code'] = 2002;
        return response()->json($appclient)
                         ->setStatusCode(200, 'CREATE_SUCCESS');

    }

    /**
     * Create new appclient.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(AppclientRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $appclient          = $this->repository->create($attributes);
            $appclient          = $appclient->presenter();
            $appclient['code']  = 2004;

            return response()->json($appclient)
                             ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }
    }

    /**
     * Show appclient for editing.
     *
     * @param Request $request
     * @param Model   $appclient
     *
     * @return json
     */
    public function edit(AppclientRequest $request, Appclient $appclient)
    {
        $appclient         = $appclient->presenter();
        $appclient['code'] = 2003;
        return response()-> json($appclient)
                        ->setStatusCode(200, 'EDIT_SUCCESS');;
    }

    /**
     * Update the appclient.
     *
     * @param Request $request
     * @param Model   $appclient
     *
     * @return json
     */
    public function update(AppclientRequest $request, Appclient $appclient)
    {
        try {

            $attributes = $request->all();

            $appclient->update($attributes);
            $appclient         = $appclient->presenter();
            $appclient['code'] = 2005;

            return response()->json($appclient)
                             ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the appclient.
     *
     * @param Request $request
     * @param Model   $appclient
     *
     * @return json
     */
    public function destroy(AppclientRequest $request, Appclient $appclient)
    {
        try {
            $t = $appclient->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('client::appclient.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
